const compareAdjacencyEntries = (item1, item2) => {
    if (item1.accession > item2.accession) {
        return -1;
    }
    if (item1.accession < item2.accession) {
        return 1;
    }
    return 0;
};
const process = (data, primaryAccession) => {
    const subcellulartreeMenu = {};
    const diseases = {};
    const interactionsMap = new Map();
    const entryStore = new Map();
    let mainEntry;
    const isoforms = [];
    const otherEntries = [];
    data.forEach((entry) => {
        const returnEntry = {
            accession: entry.accession,
            interactors: [],
        };
        if (entry.accession === primaryAccession) {
            mainEntry = returnEntry;
        }
        else if (entry.accession.startsWith(primaryAccession)) {
            isoforms.push(returnEntry);
        }
        else {
            otherEntries.push(returnEntry);
        }
    });
    const adjacencyMap = [
        mainEntry,
        ...isoforms.sort(compareAdjacencyEntries),
        ...otherEntries.sort(compareAdjacencyEntries),
    ];
    const accessionList = adjacencyMap.map(({ accession }) => accession);
    data.forEach((entry) => {
        entryStore.set(entry.accession, {
            name: entry.name,
            proteinExistence: entry.proteinExistence,
            taxonomy: entry.taxonomy,
            diseases: entry.diseases,
            subcellularLocations: entry.subcellularLocations,
        });
        entry.interactions.forEach((interaction) => {
            // Filter out any interactor not in the original list
            if (accessionList.includes(interaction.accession1) &&
                accessionList.includes(interaction.accession2)) {
                const id = `${interaction.accession1}${interaction.accession2}`;
                interactionsMap.set(id, interaction);
                const foundEntry = adjacencyMap.find(({ accession }) => accession === entry.accession);
                if (accessionList.includes(interaction.accession1) &&
                    accessionList.includes(interaction.accession2)) {
                    foundEntry.interactors.push(interaction.accession1 === entry.accession
                        ? interaction.accession2
                        : interaction.accession1);
                }
            }
        });
        // Parse supporting data for filters
        if (entry.subcellularLocations) {
            entry.subcellularLocations
                .filter((d) => d.locations)
                .forEach((location) => {
                for (const actualLocation of location.locations) {
                    subcellulartreeMenu[actualLocation.location.value] =
                        subcellulartreeMenu[actualLocation.location.value]
                            ? [
                                ...subcellulartreeMenu[actualLocation.location.value],
                                entry.accession,
                            ]
                            : [entry.accession];
                }
            });
        }
        if (entry.diseases) {
            for (const disease of entry.diseases) {
                if (disease.diseaseId) {
                    diseases[disease.diseaseId] = diseases[disease.diseaseId]
                        ? [...diseases[disease.diseaseId], entry.accession]
                        : [entry.accession];
                }
            }
        }
    });
    const filterConfig = [
        {
            name: "subcellularLocations",
            label: "Subcellular location",
            type: "tree",
            items: subcellulartreeMenu,
        },
        {
            name: "diseases",
            label: "Diseases",
            items: diseases,
        },
    ];
    return {
        // Filter empty ones - these happen because they interact with isoforms which have been removed
        adjacencyMap: adjacencyMap.filter((item) => !!item.interactors.length),
        interactionsMap,
        entryStore,
        filterConfig,
    };
};
export default process;
//# sourceMappingURL=apiLoader.js.map