var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
/* eslint-disable no-param-reassign */
import { html, LitElement } from "lit";
// eslint-disable-next-line import/extensions
import { customElement, property, state } from "lit/decorators.js";
import { load } from "data-loader";
import { select } from "d3";
import _intersection from "lodash-es/intersection";
import process from "./apiLoader";
import drawAdjacencyGraph from "./AdjacencyGraph";
// import drawFilters, { getNameAsHTMLId } from "./filters";
import styles from "./styles";
import { FILTER_SELECT } from "./interaction-filters";
const dispatchLoadedEvent = (el, error) => {
    el.dispatchEvent(new CustomEvent("protvista-event", {
        detail: {
            loaded: true,
            error,
        },
        bubbles: true,
    }));
};
const filterAdjacencyMap = (adjacencyMap, filteredAccessions) => {
    if (!filteredAccessions) {
        return adjacencyMap;
    }
    return adjacencyMap.map(({ accession, interactors }) => ({
        accession,
        interactors: interactors.filter((interactor) => filteredAccessions.includes(interactor) ||
            filteredAccessions.includes(accession)),
    }));
};
let InteractionViewer = class InteractionViewer extends LitElement {
    constructor() {
        super(...arguments);
        this.nodes = null;
        this.maxInteractors = 50;
    }
    handleFilterSelection(event) {
        if (event.detail.length === 0) {
            // Reset filters
            this.filteredAccessions = undefined;
        }
        else if (!this.filteredAccessions ||
            this.filteredAccessions.length === 0) {
            // First filter applied
            this.filteredAccessions = event.detail;
        }
        else {
            // AND additional filters
            this.filteredAccessions = _intersection(event.detail, this.filteredAccessions);
        }
    }
    connectedCallback() {
        super.connectedCallback();
        this.addEventListener(FILTER_SELECT, this.handleFilterSelection);
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this.removeEventListener(FILTER_SELECT, this.handleFilterSelection);
    }
    getNodeByAccession(accession) {
        return this.nodes.find((node) => node.accession === accession);
    }
    updated(changedProperties) {
        // Only run this if it's the accession that has changed
        if (changedProperties.has("accession")) {
            if (!this.accession) {
                return;
            }
            load(`https://www.ebi.ac.uk/proteins/api/proteins/interaction/${this.accession}.json`).then((response) => {
                this.processedData = process(response.payload, this.accession);
            });
        }
        const container = this.shadowRoot.getElementById("container");
        const tooltip = this.shadowRoot.getElementById("tooltip");
        // Return early, this means we are not displaying the visualisation
        if (!container || !tooltip) {
            return;
        }
        container.style.display = "block";
        container.style.minHeight = "6em";
        // clear all previous vis
        select(container).select(".interaction-title").remove();
        select(container).select("svg").remove();
        select(container).select(".interaction-tooltip").remove();
        if (this.processedData) {
            dispatchLoadedEvent(this);
            drawAdjacencyGraph(container, this.accession, Object.assign(Object.assign({}, this.processedData), { adjacencyMap: filterAdjacencyMap(this.processedData.adjacencyMap, this.filteredAccessions) }), tooltip, this);
        }
    }
    // eslint-disable-next-line class-methods-use-this
    render() {
        var _a;
        let count;
        if (this.processedData) {
            const { adjacencyMap } = this.processedData;
            // Filter out itself and its isoforms
            count = adjacencyMap.filter(({ accession }) => !accession.startsWith(this.accession)).length;
        }
        // No need to display
        if (count <= 1 || count > this.maxInteractors) {
            return html ``;
        }
        return html ` <p class="interaction-title">
        ${this.accession} has binary interactions with ${count} proteins
      </p>

      <interaction-filters
        filterConfig=${JSON.stringify((_a = this.processedData) === null || _a === void 0 ? void 0 : _a.filterConfig)}
      ></interaction-filters>
      <div id="container"></div>
      <interaction-tooltip id="tooltip"></interaction-tooltip>`;
    }
};
InteractionViewer.styles = styles;
__decorate([
    property({ type: String, reflect: true })
], InteractionViewer.prototype, "accession", void 0);
__decorate([
    property({ type: Number, reflect: true })
], InteractionViewer.prototype, "maxInteractors", void 0);
__decorate([
    state()
], InteractionViewer.prototype, "processedData", void 0);
__decorate([
    state()
], InteractionViewer.prototype, "filteredAccessions", void 0);
InteractionViewer = __decorate([
    customElement("interaction-viewer")
], InteractionViewer);
export default InteractionViewer;
//# sourceMappingURL=interaction-viewer.js.map